@@ -13,8 +13,14 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## usage:  [P, w] = __power (b, a, [, nfft [, Fs]] [, range] [, units])
-## 
+## -*- texinfo -*-
+## @deftypefn  {Function File} {[@var{P}, @var{w}] =} __power (@var{b}, @var{a})
+## @deftypefnx {Function File} {[@dots{}] =} __power (@var{b}, @var{a}, @var{nfft})
+## @deftypefnx {Function File} {[@dots{}] =} __power (@var{b}, @var{a}, @var{nfft}, @var{Fs})
+## @deftypefnx {Function File} {[@dots{}] =} __power (@var{b}, @var{a}, @var{nfft}, @var{Fs}, @var{range})
+## @deftypefnx {Function File} {[@dots{}] =} __power (@var{b}, @var{a}, @var{nfft}, @var{Fs}, @var{range}, @var{units})
+## @deftypefnx {Function File} {} __power (@dots{})
+##
 ## Plot the power spectrum of the given ARMA model.
 ##
 ## b, a: filter coefficients (b=numerator, a=denominator)
@@ -28,11 +34,13 @@
 ## Returns P, the magnitude vector, and w, the frequencies at which it
 ## is sampled.  If there are no return values requested, then plot the power
 ## spectrum and don't return anything.
+## @end deftypefn
 
-## TODO: consider folding this into freqz --- just one more parameter to
-## TODO:    distinguish between 'linear', 'log', 'logsquared' and 'squared'
+## FIXME: consider folding this into freqz --- just one more parameter to
+##        distinguish between 'linear', 'log', 'logsquared' and 'squared'
 
 function [varargout] = __power (b, a, varargin)
+
   if (nargin < 2 || nargin > 6) print_usage; endif
 
   nfft = [];
@@ -64,14 +72,14 @@ function [varargout] = __power (b, a, varargin)
       usage(usagestr);
     endif
   endfor
-  
+
   if isempty(nfft); nfft = 256; endif
   if isempty(Fs); Fs = 2; endif
   if isempty(range)
     range = 'half';
     range_fact = 2.0;
-    endif
-  
+  endif
+
   [P, w] = freqz(b, a, nfft, range, Fs);
 
   P = (range_fact/Fs)*(P.*conj(P));
@@ -86,4 +94,3 @@ function [varargout] = __power (b, a, varargin)
   if nargout >= 2, varargout{2} = w; endif
 
 endfunction
-
