@@ -14,24 +14,25 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{w}] =} bohmanwin(@var{L})
-## Compute the Bohman window of lenght L.
-## @seealso{rectwin,  bartlett}
+## @deftypefn {Function File} {[@var{w}] =} bohmanwin (@var{L})
+## Compute the Bohman window of length @var{L}.
+## @seealso{rectwin, bartlett}
 ## @end deftypefn
 
 function [w] = bohmanwin(L)
+
   if (nargin < 1)
     print_usage
   elseif(! isscalar(L))
     error("L must be a number");
   elseif(L < 0)
     error('L must be positive');
-  end
+  endif
 
   if(L ~= floor(L))
     L = round(L);
     warning('L rounded to the nearest integer.');
-  end
+  endif
 
   if(L == 0)
     w = [];
@@ -47,5 +48,6 @@ function [w] = bohmanwin(L)
     w(1) = 0;
     w(length(w))=0;
     w = w';
-  end
+  endif
+
 endfunction
