@@ -15,9 +15,17 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
+## -*- texinfo -*-
+## @deftypefn  {Function File} {[@var{b}, @var{a}] =} butter (@var{n}, @var{Wc})
+## @deftypefnx {Function File} {[@var{b}, @var{a}] =} butter (@var{n}, @var{Wc}, "high")
+## @deftypefnx {Function File} {[@var{b}, @var{a}] =} butter (@var{n}, [@var{Wl}, @var{Wh}])
+## @deftypefnx {Function File} {[@var{b}, @var{a}] =} butter (@var{n}, [@var{Wl}, @var{Wh}], "stop")
+## @deftypefnx {Function File} {[@var{z}, @var{p}, @var{g}] =} butter (@dots{})
+## @deftypefnx {Function File} {[@var{a}, @var{b}, @var{c}, @var{d}] =} butter (@dots{})
+## @deftypefnx {Function File} {[@dots{}] =} butter (@dots{}, "s")
 ## Generate a butterworth filter.
 ## Default is a discrete space (Z) filter.
-## 
+##
 ## [b,a] = butter(n, Wc)
 ##    low pass filter with cutoff pi*Wc radians
 ##
@@ -33,38 +41,39 @@
 ## [z,p,g] = butter(...)
 ##    return filter as zero-pole-gain rather than coefficients of the
 ##    numerator and denominator polynomials.
-## 
+##
 ## [...] = butter(...,'s')
 ##     return a Laplace space filter, W can be larger than 1.
-## 
-## [a,b,c,d] = butter(...)
-##  return  state-space matrices 
 ##
-## References: 
+## [a,b,c,d] = butter(...)
+##  return  state-space matrices
+##
+## References:
 ##
 ## Proakis & Manolakis (1992). Digital Signal Processing. New York:
 ## Macmillan Publishing Company.
+## @end deftypefn
 
 function [a, b, c, d] = butter (n, W, varargin)
-  
+
   if (nargin>4 || nargin<2) || (nargout>4 || nargout<2)
     print_usage;
-  end
+  endif
 
   ## interpret the input parameters
   if (!(length(n)==1 && n == round(n) && n > 0))
     error ("butter: filter order n must be a positive integer");
-  end
+  endif
 
   stop = 0;
   digital = 1;
   for i=1:length(varargin)
     switch varargin{i}
-    case 's', digital = 0;
-    case 'z', digital = 1;
-    case { 'high', 'stop' }, stop = 1;
-    case { 'low',  'pass' }, stop = 0;
-    otherwise,  error ("butter: expected [high|stop] or [s|z]");
+      case 's', digital = 0;
+      case 'z', digital = 1;
+      case { 'high', 'stop' }, stop = 1;
+      case { 'low',  'pass' }, stop = 0;
+      otherwise,  error ("butter: expected [high|stop] or [s|z]");
     endswitch
   endfor
 
@@ -94,7 +103,7 @@ function [a, b, c, d] = butter (n, W, varargin)
   ## source: Kuc
   C = 1; # default cutoff frequency
   pole = C*exp(1i*pi*(2*[1:n] + n - 1)/(2*n));
-  if mod(n,2) == 1, pole((n+1)/2) = -1; end  # pure real value at exp(i*pi)
+  if mod(n,2) == 1, pole((n+1)/2) = -1; endif  # pure real value at exp(i*pi)
   zero = [];
   gain = C^n;
 
@@ -103,11 +112,11 @@ function [a, b, c, d] = butter (n, W, varargin)
 
   ## Use bilinear transform to convert poles to the z plane
   if digital
-     [zero, pole, gain] = bilinear(zero, pole, gain, T);
+    [zero, pole, gain] = bilinear(zero, pole, gain, T);
   endif
 
   ## convert to the correct output form
-  if nargout==2, 
+  if nargout==2,
     a = real(gain*poly(zero));
     b = real(poly(pole));
   elseif nargout==3,
@@ -115,7 +124,7 @@ function [a, b, c, d] = butter (n, W, varargin)
     b = pole;
     c = gain;
   else
-    ## output ss results 
+    ## output ss results
     [a, b, c, d] = zp2ss (zero, pole, gain);
   endif
 
@@ -123,12 +132,12 @@ endfunction
 
 %!shared sf, sf2, off_db
 %! off_db = 0.5;
-%! ##Sampling frequency must be that high to make the low pass filters pass.
+%! ## Sampling frequency must be that high to make the low pass filters pass.
 %! sf = 6000; sf2 = sf/2;
 %! data=[sinetone(5,sf,10,1),sinetone(10,sf,10,1),sinetone(50,sf,10,1),sinetone(200,sf,10,1),sinetone(400,sf,10,1)];
 
 %!test
-%! ##Test low pass order 1 with 3dB @ 50Hz
+%! ## Test low pass order 1 with 3dB @ 50Hz
 %! data=[sinetone(5,sf,10,1),sinetone(10,sf,10,1),sinetone(50,sf,10,1),sinetone(200,sf,10,1),sinetone(400,sf,10,1)];
 %! [b, a] = butter ( 1, 50 / sf2 );
 %! filtered = filter ( b, a, data );
@@ -136,7 +145,7 @@ endfunction
 %! assert ( [ damp_db( 4 ) - damp_db( 5 ), damp_db( 1 : 3 ) ], [ 6 0 0 -3 ], off_db )
 
 %!test
-%! ##Test low pass order 4 with 3dB @ 50Hz
+%! ## Test low pass order 4 with 3dB @ 50Hz
 %! data=[sinetone(5,sf,10,1),sinetone(10,sf,10,1),sinetone(50,sf,10,1),sinetone(200,sf,10,1),sinetone(400,sf,10,1)];
 %! [b, a] = butter ( 4, 50 / sf2 );
 %! filtered = filter ( b, a, data );
@@ -144,7 +153,7 @@ endfunction
 %! assert ( [ damp_db( 4 ) - damp_db( 5 ), damp_db( 1 : 3 ) ], [ 24 0 0 -3 ], off_db )
 
 %!test
-%! ##Test high pass order 1 with 3dB @ 50Hz
+%! ## Test high pass order 1 with 3dB @ 50Hz
 %! data=[sinetone(5,sf,10,1),sinetone(10,sf,10,1),sinetone(50,sf,10,1),sinetone(200,sf,10,1),sinetone(400,sf,10,1)];
 %! [b, a] = butter ( 1, 50 / sf2, "high" );
 %! filtered = filter ( b, a, data );
@@ -152,7 +161,7 @@ endfunction
 %! assert ( [ damp_db( 2 ) - damp_db( 1 ), damp_db( 3 : end ) ], [ 6 -3 0 0 ], off_db )
 
 %!test
-%! ##Test high pass order 4 with 3dB @ 50Hz
+%! ## Test high pass order 4 with 3dB @ 50Hz
 %! data=[sinetone(5,sf,10,1),sinetone(10,sf,10,1),sinetone(50,sf,10,1),sinetone(200,sf,10,1),sinetone(400,sf,10,1)];
 %! [b, a] = butter ( 4, 50 / sf2, "high" );
 %! filtered = filter ( b, a, data );
@@ -166,11 +175,11 @@ endfunction
 %! filtered = filter(b,a,data);
 %!
 %! clf
-%! subplot ( columns ( filtered ), 1, 1) 
+%! subplot ( columns ( filtered ), 1, 1)
 %! plot(filtered(:,1),";Impulse response;")
-%! subplot ( columns ( filtered ), 1, 2 ) 
+%! subplot ( columns ( filtered ), 1, 2 )
 %! plot(filtered(:,2),";25Hz response;")
-%! subplot ( columns ( filtered ), 1, 3 ) 
+%! subplot ( columns ( filtered ), 1, 3 )
 %! plot(filtered(:,3),";50Hz response;")
-%! subplot ( columns ( filtered ), 1, 4 ) 
+%! subplot ( columns ( filtered ), 1, 4 )
 %! plot(filtered(:,4),";100Hz response;")
