@@ -13,15 +13,18 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
+## -*- texinfo -*-
+## @deftypefn  {Function File} {[@var{n}, @var{Wc}] =} buttord (@var{Wp}, @var{Ws}, @var{Rp}, @var{Rs})
+## @deftypefnx {Function File} {[@var{n}, @var{Wc}] =} buttord ([@var{Wp1}, @var{Wp2}], [@var{Ws1}, @var{Ws2}], @var{Rp}, @var{Rs})
 ## Compute butterworth filter order and cutoff for the desired response
-## characteristics. Rp is the allowable decibels of ripple in the pass 
+## characteristics. Rp is the allowable decibels of ripple in the pass
 ## band. Rs is the minimum attenuation in the stop band.
 ##
 ## [n, Wc] = buttord(Wp, Ws, Rp, Rs)
 ##     Low pass (Wp<Ws) or high pass (Wp>Ws) filter design.  Wp is the
 ##     pass band edge and Ws is the stop band edge.  Frequencies are
 ##     normalized to [0,1], corresponding to the range [0,Fs/2].
-## 
+##
 ## [n, Wc] = buttord([Wp1, Wp2], [Ws1, Ws2], Rp, Rs)
 ##     Band pass (Ws1<Wp1<Wp2<Ws2) or band reject (Wp1<Ws1<Ws2<Wp2)
 ##     filter design. Wp gives the edges of the pass band, and Ws gives
@@ -35,9 +38,11 @@
 ## significantly overdesigns.  Artificially dividing N by 2 in this case
 ## helps a lot, but it still overdesigns.
 ##
-## See also: butter
+## @seealso{butter}
+## @end deftypefn
 
 function [n, Wc] = buttord(Wp, Ws, Rp, Rs)
+
   if nargin != 4
     print_usage;
   elseif length(Wp) != length(Ws)
@@ -46,23 +51,23 @@ function [n, Wc] = buttord(Wp, Ws, Rp, Rs)
     error("buttord: Wp,Ws must have length 1 or 2");
   elseif length(Wp) == 2 && (all(Wp>Ws) || all(Ws>Wp) || diff(Wp)<=0 || diff(Ws)<=0)
     error("buttord: Wp(1)<Ws(1)<Ws(2)<Wp(2) or Ws(1)<Wp(1)<Wp(2)<Ws(2)");
-  end
+  endif
 
   if length(Wp) == 2
     warning("buttord: seems to overdesign bandpass and bandreject filters");
-  end
+  endif
 
   T = 2;
-  
+
   ## if high pass, reverse the sense of the test
   stop = find(Wp > Ws);
   Wp(stop) = 1-Wp(stop); # stop will be at most length 1, so no need to
   Ws(stop) = 1-Ws(stop); # subtract from ones(1,length(stop))
-  
+
   ## warp the target frequencies according to the bilinear transform
   Ws = (2/T)*tan(pi*Ws./T);
   Wp = (2/T)*tan(pi*Wp./T);
-  
+
   ## compute minimum n which satisfies all band edge conditions
   ## the factor 1/length(Wp) is an artificial correction for the
   ## band pass/stop case, which otherwise significantly overdesigns.
@@ -75,8 +80,8 @@ function [n, Wc] = buttord(Wp, Ws, Rp, Rs)
 
   ## unwarp the returned frequency
   Wc = atan(T/2*Wc)*T/pi;
-  
+
   ## if high pass, reverse the sense of the test
   Wc(stop) = 1-Wc(stop);
-    
+
 endfunction
