@@ -13,11 +13,13 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## usage:  cceps (x [, correct])
-##
-## Returns the complex cepstrum of the vector x.
-## If the optional argument correct has the value 1, a correction
+## -*- texinfo -*-
+## @deftypefn  {Function File} {} cceps (@var{x})
+## @deftypefnx {Function File} {} cceps (@var{x}, @var{correct})
+## Return the complex cepstrum of the vector @var{x}.
+## If the optional argument @var{correct} has the value 1, a correction
 ## method is applied.  The default is not to do this.
+## @end deftypefn
 
 ## Author: Andreas Weingessel <Andreas.Weingessel@ci.tuwien.ac.at>
 ## Apr 1, 1994
@@ -42,14 +44,14 @@ function cep = cceps (x, c)
   endif
 
   bad_signal_message = ["cceps:  bad signal x, ", ...
-      "some Fourier coefficients are zero."];
-  
+                        "some Fourier coefficients are zero."];
+
   F = fft (x);
   if (min (abs (F)) == 0)
     error (bad_signal_message);
   endif
 
-  # determine if correction necessary
+  ## determine if correction necessary
   half = fix (nr / 2);
   cor = 0;
   if (2 * half == nr)
@@ -64,11 +66,11 @@ function cep = cceps (x, c)
 
   cep = fftshift (ifft (log (F)));
 
-  # make result real
+  ## make result real
   if (c)
     cep = real (cep);
-    if (cor)      
-      # make cepstrum of same length as input vector
+    if (cor)
+      ## make cepstrum of same length as input vector
       cep (nr) = 0;
     endif
   endif
