@@ -14,21 +14,25 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
+## -*- texinfo -*-
+## @deftypefn  {Function File} {[@var{n}, @var{Wc}] =} cheb1ord (@var{Wp}, @var{Ws}, @var{Rp}, @var{Rs})
+## @deftypefnx {Function File} {[@var{n}, @var{Wc}] =} cheb1ord ([@var{Wp1}, @var{Wp2}], [@var{Ws1}, @var{Ws2}], @var{Rp}, @var{Rs})
 ## Compute chebyshev type I filter order and cutoff for the desired response
-## characteristics. Rp is the allowable decibels of ripple in the pass 
+## characteristics. Rp is the allowable decibels of ripple in the pass
 ## band. Rs is the minimum attenuation in the stop band.
 ##
 ## [n, Wc] = cheb1ord(Wp, Ws, Rp, Rs)
 ##     Low pass (Wp<Ws) or high pass (Wp>Ws) filter design.  Wp is the
 ##     pass band edge and Ws is the stop band edge.  Frequencies are
 ##     normalized to [0,1], corresponding to the range [0,Fs/2].
-## 
+##
 ## [n, Wc] = cheb1ord([Wp1, Wp2], [Ws1, Ws2], Rp, Rs)
 ##     Band pass (Ws1<Wp1<Wp2<Ws2) or band reject (Wp1<Ws1<Ws2<Wp2)
 ##     filter design. Wp gives the edges of the pass band, and Ws gives
 ##     the edges of the stop band.
 ##
-## See also: cheby1
+## @seealso{cheby1}
+## @end deftypefn
 
 function [n, Wc] = cheb1ord(Wp, Ws, Rp, Rs)
 
@@ -39,9 +43,9 @@ function [n, Wc] = cheb1ord(Wp, Ws, Rp, Rs)
   elseif length(Wp) != 1 && length(Wp) != 2
     error("cheb1ord: Wp,Ws must have length 1 or 2");
   elseif length(Wp) == 2 && ...
-        (all(Wp>Ws) || all(Ws>Wp) || diff(Wp)<=0 || diff(Ws)<=0)
+          (all(Wp>Ws) || all(Ws>Wp) || diff(Wp)<=0 || diff(Ws)<=0)
     error("cheb1ord: Wp(1)<Ws(1)<Ws(2)<Wp(2) or Ws(1)<Wp(1)<Wp(2)<Ws(2)");
-  end
+  endif
 
   T = 2;
 
@@ -61,16 +65,16 @@ function [n, Wc] = cheb1ord(Wp, Ws, Rp, Rs)
       error ("band reject is not implement yet.");
     endif;
   else
-   ## if high pass, reverse the sense of the test
-   if (length(Wp) == 1)
+    ## if high pass, reverse the sense of the test
+    if (length(Wp) == 1)
       Wa = Wp/Ws;
     else
-      ## band pass 
+      ## band pass
       Wa=(Ws.^2 - Wp(1)*Wp(2))./(Ws*(Wp(1)-Wp(2)));
     endif;
   endif;
   Wa = min(abs(Wa));
-  
+
   ## compute minimum n which satisfies all band edge conditions
   stop_atten = 10^(abs(Rs)/10);
   pass_atten = 10^(abs(Rp)/10);
@@ -79,43 +83,43 @@ function [n, Wc] = cheb1ord(Wp, Ws, Rp, Rs)
 endfunction
 
 %!demo
-%! Fs = 10000; 
+%! Fs = 10000;
 %! [n, Wc] = cheb1ord (1000/(Fs/2), 1200/(Fs/2), 0.5, 29);
 %!
 %! subplot (221);
+%! plot ([0, 1000, 1000, 0, 0], [0, 0, -0.5, -0.5, 0], ";;");
+%! hold on;
 %! axis ([ 0, 1500, -1, 0]);
 %! title("Pass band Wp=1000 Rp=0.5");
 %! xlabel("Frequency (Hz)");
 %! ylabel("Attenuation (dB)");
 %! grid;
-%! plot ([0, 1000, 1000, 0, 0], [0, 0, -0.5, -0.5, 0], ";;");
-%! hold on;
 %! [b, a] = cheby1 (n, 0.5, Wc);
 %! [h, w] = freqz (b, a, [], Fs);
 %! plot (w, 20*log10(abs(h)), ";;");
 %! hold off;
 %!
 %! subplot (222);
+%! plot ([1200, Fs/2, Fs/2, 1200, 1200], [-29, -29, -500, -500, -29], ";;");
+%! hold on;
 %! axis ([ 0, Fs/2, -250, 0]);
 %! title("Stop band Ws=1200 Rs=29");
 %! xlabel("Frequency (Hz)");
 %! ylabel("Attenuation (dB)");
 %! grid;
-%! plot ([1200, Fs/2, Fs/2, 1200, 1200], [-29, -29, -500, -500, -29], ";;");
-%! hold on;
 %! [b, a] = cheby1 (n, 0.5, Wc);
 %! [h, w] = freqz (b, a, [], Fs);
 %! plot (w, 20*log10(abs(h)), ";;");
 %! hold off;
 %!
 %! subplot (223);
+%! plot ([0, 1000, 1000, 0, 0], [0, 0, -0.5, -0.5, 0], ";;");
+%! hold on;
 %! axis ([ 990, 1010, -0.6, -0.4]);
 %! title("Pass band detail Wp=1000 Rp=0.5");
 %! xlabel("Frequency (Hz)");
 %! ylabel("Attenuation (dB)");
 %! grid;
-%! plot ([0, 1000, 1000, 0, 0], [0, 0, -0.5, -0.5, 0], ";;");
-%! hold on;
 %! [b, a] = cheby1 (n, 0.5, Wc);
 %! [h, w] = freqz (b, a, [990:1010], Fs);
 %! plot (w, 20*log10(abs(h)), ";filter n;");
@@ -128,13 +132,13 @@ endfunction
 %! hold off;
 %!
 %! subplot (224);
+%! plot ([1200, Fs/2, Fs/2, 1200, 1200], [-29, -29, -500, -500, -29], ";;");
+%! hold on;
 %! axis ([ 1190, 1210, -40, -20]);
 %! title("Stop band detail Wp=1200 Rp=29");
 %! xlabel("Frequency (Hz)");
 %! ylabel("Attenuation (dB)");
 %! grid;
-%! plot ([1200, Fs/2, Fs/2, 1200, 1200], [-29, -29, -500, -500, -29], ";;");
-%! hold on;
 %! [b, a] = cheby1 (n, 0.5, Wc);
 %! [h, w] = freqz (b, a, [1190:1210], Fs);
 %! plot (w, 20*log10(abs(h)), ";filter n;");
