@@ -13,23 +13,27 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
+## -*- texinfo -*-
+## @deftypefn  {Function File} {[@var{n}, @var{Wc}] =} cheb2ord (@var{Wp}, @var{Ws}, @var{Rp}, @var{Rs})
+## @deftypefnx {Function File} {[@var{n}, @var{Wc}] =} cheb2ord ([@var{Wp1}, @var{Wp2}], [@var{Ws1}, @var{Ws2}], @var{Rp}, @var{Rs})
 ## Compute chebyshev type II filter order and cutoff for the desired response
-## characteristics. Rp is the allowable decibels of ripple in the pass 
+## characteristics. Rp is the allowable decibels of ripple in the pass
 ## band. Rs is the minimum attenuation in the stop band.
 ##
 ## [n, Wc] = cheb2ord(Wp, Ws, Rp, Rs)
 ##     Low pass (Wp<Ws) or high pass (Wp>Ws) filter design.  Wp is the
 ##     pass band edge and Ws is the stop band edge.  Frequencies are
 ##     normalized to [0,1], corresponding to the range [0,Fs/2].
-## 
+##
 ## [n, Wc] = cheb2ord([Wp1, Wp2], [Ws1, Ws2], Rp, Rs)
 ##     Band pass (Ws1<Wp1<Wp2<Ws2) or band reject (Wp1<Ws1<Ws2<Wp2)
 ##     filter design. Wp gives the edges of the pass band, and Ws gives
 ##     the edges of the stop band.
 ##
-## Theory: 
+## Theory:
 ##
-## See also: cheby2
+## @seealso{cheby2}
+## @end deftypefn
 
 function [n, Wc] = cheb2ord(Wp, Ws, Rp, Rs)
 
@@ -42,7 +46,7 @@ function [n, Wc] = cheb2ord(Wp, Ws, Rp, Rs)
   elseif length(Wp) == 2 && ...
           (all(Wp>Ws) || all(Ws>Wp) || diff(Wp)<=0 || diff(Ws)<=0)
     error("cheb2ord: Wp(1)<Ws(1)<Ws(2)<Wp(2) or Ws(1)<Wp(1)<Wp(2)<Ws(2)");
-  end
+  endif
 
   T = 2;
 
@@ -66,7 +70,7 @@ function [n, Wc] = cheb2ord(Wp, Ws, Rp, Rs)
    if (length(Wp) == 1)
       Wa = Ws/Wp;
     else
-      ## band pass 
+      ## band pass
       Wa=(Wp.^2 - Ws(1)*Ws(2))./(Wp*(Ws(1)-Ws(2)));
     endif;
   endif;
@@ -76,11 +80,11 @@ function [n, Wc] = cheb2ord(Wp, Ws, Rp, Rs)
   stop_atten = 10^(abs(Rs)/10);
   pass_atten = 10^(abs(Rp)/10);
   n = ceil(acosh(sqrt((stop_atten-1)/(pass_atten-1)))/acosh(1/Wa));
-    
+
 endfunction
 
 %!demo
-%! Fs = 10000; 
+%! Fs = 10000;
 %! [n, Wc] = cheb2ord (1000/(Fs/2), 1200/(Fs/2), 0.5, 29);
 %!
 %! subplot (221);
