@@ -13,25 +13,32 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## usage: y = decimate(x, q [, n] [, ftype])
+## -*- texinfo -*-
+## @deftypefn  {Function File} {@var{y} =} decimate (@var{x}, @var{q})
+## @deftypefnx {Function File} {@var{y} =} decimate (@var{x}, @var{q}, @var{n})
+## @deftypefnx {Function File} {@var{y} =} decimate (@var{x}, @var{q}, @var{n}, @var{ftype})
 ##
-## Downsample the signal x by a factor of q, using an order n filter
-## of ftype 'fir' or 'iir'.  By default, an order 8 Chebyshev type I
-## filter is used or a 30 point FIR filter if ftype is 'fir'.  Note
-## that q must be an integer for this rate change method.
+## Downsample the signal @var{x} by a factor of @var{q}, using an order @var{n}
+## filter of @var{ftype} "fir" or "iir".  By default, an order 8 Chebyshev
+## type I filter is used or a 30 point FIR filter if @var{ftype} is "fir".
+## Note that @var{q} must be an integer for this rate change method.
 ##
-## Example
-##    ## Generate a signal that starts away from zero, is slowly varying
-##    ## at the start and quickly varying at the end, decimate and plot.
-##    ## Since it starts away from zero, you will see the boundary
-##    ## effects of the antialiasing filter clearly.  Next you will see
-##    ## how it follows the curve nicely in the slowly varying early
-##    ## part of the signal, but averages the curve in the quickly
-##    ## varying late part of the signal.
-##    t=0:0.01:2; x=chirp(t,2,.5,10,'quadratic')+sin(2*pi*t*0.4); 
-##    y = decimate(x,4);   # factor of 4 decimation
-##    stem(t(1:121)*1000,x(1:121),"-g;Original;"); hold on; # plot original
-##    stem(t(1:4:121)*1000,y(1:31),"-r;Decimated;"); hold off; # decimated
+## Example:
+## @example
+## ## Generate a signal that starts away from zero, is slowly varying
+## ## at the start and quickly varying at the end, decimate and plot.
+## ## Since it starts away from zero, you will see the boundary
+## ## effects of the antialiasing filter clearly.  Next you will see
+## ## how it follows the curve nicely in the slowly varying early
+## ## part of the signal, but averages the curve in the quickly
+## ## varying late part of the signal.
+## t = 0:0.01:2;
+## x = chirp (t, 2, .5, 10, "quadratic") + sin (2*pi*t*0.4);
+## y = decimate (x, 4);
+## stem (t(1:121) * 1000, x(1:121), "-g;Original;"); hold on; # original
+## stem (t(1:4:121) * 1000, y(1:31), "-r;Decimated;"); hold off; # decimated
+## @end example
+## @end deftypefn
 
 function y = decimate(x, q, n, ftype)
 
@@ -46,9 +53,9 @@ function y = decimate(x, q, n, ftype)
     n=[];
   elseif nargin==3
     if ischar(n)
-      ftype=n; 
+      ftype=n;
       n=[];
-    else 
+    else
       ftype='iir';
     endif
   endif
@@ -66,10 +73,11 @@ function y = decimate(x, q, n, ftype)
     y=filtfilt(b,a,x);
   endif
   y = y(1:q:length(x));
+
 endfunction
 
 %!demo
-%! t=0:0.01:2; x=chirp(t,2,.5,10,'quadratic')+sin(2*pi*t*0.4); 
+%! t=0:0.01:2; x=chirp(t,2,.5,10,'quadratic')+sin(2*pi*t*0.4);
 %! y = decimate(x,4);   # factor of 4 decimation
 %! stem(t(1:121)*1000,x(1:121),"-g;Original;"); hold on; # plot original
 %! stem(t(1:4:121)*1000,y(1:31),"-r;Decimated;"); hold off; # decimated
