@@ -13,28 +13,33 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## Usage: H = freqs(B,A,W);
+## -*- texinfo -*-
+## @deftypefn  {Function File} {@var{h} =} freqs (@var{b}, @var{a}, @var{w})
+## @deftypefnx {Function File} {} freqs (@var{b}, @var{a}, @var{w})
 ##
-## Compute the s-plane frequency response of the IIR filter B(s)/A(s) as 
+## Compute the s-plane frequency response of the IIR filter B(s)/A(s) as
 ## H = polyval(B,j*W)./polyval(A,j*W).  If called with no output
 ## argument, a plot of magnitude and phase are displayed.
 ##
 ## Example:
-##    B = [1 2]; A = [1 1];
-##    w = linspace(0,4,128);
-##    freqs(B,A,w);
+## @example
+## b = [1 2]; a = [1 1];
+## w = linspace (0, 4, 128);
+## freqs (b, a, w);
+## @end example
+## @end deftypefn
 
 function [H] = freqs(B,A,W)
 
   if (nargin ~= 3 || nargout>1)
     print_usage;
-  end
+  endif
 
   H = polyval(B,j*W)./polyval(A,j*W);
 
   if nargout<1
     freqs_plot(W,H);
-  end
+  endif
 
 endfunction
 
