@@ -14,16 +14,18 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{y}] =} gauspuls(@var{t},@var{fc},@var{bw})
+## @deftypefn {Function File} {[@var{y}] =} gauspuls (@var{t},@var{fc},@var{bw})
 ## Return the Gaussian modulated sinusoidal pulse.
 ## @end deftypefn
 
 function [y] = gauspuls(t, fc = 1e3, bw = 0.5)
-  if nargin<1, print_usage; end
-  if fc < 0 , error("fc must be positive"); end
-  if bw <= 0, error("bw must be stricltly positive"); end
+
+  if nargin<1, print_usage; endif
+  if fc < 0 , error("fc must be positive"); endif
+  if bw <= 0, error("bw must be stricltly positive"); endif
 
   fv = -(bw.^2.*fc.^2)/(8.*log(10.^(-6/20)));
-  tv = 1/(4.*pi.^2.*fv); 
+  tv = 1/(4.*pi.^2.*fv);
   y = exp(-t.*t/(2.*tv)).*cos(2.*pi.*fc.*t);
+
 endfunction
