@@ -13,20 +13,22 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## usage: w = gausswin(L, a)
+## -*- texinfo -*-
+## @deftypefn {Function File} {@var{w} =} gausswin (@var{L}, @var{a})
 ##
-## Generate an L-point gaussian window of the given width. Use larger a
-## for a narrow window.  Use larger L for a smoother curve. 
+## Generate an @var{L}-point gaussian window of the given width.  Use larger
+## @var{a} for a narrow window.  Use larger @var{L} for a smoother curve.
 ##
 ##     w = exp ( -(a*x)^2/2 )
 ##
 ## for x = linspace(-(L-1)/L, (L-1)/L, L)
+## @end deftypefn
 
 function x = gausswin(L, w)
 
   if nargin < 1 || nargin > 2
     print_usage;
-  end
+  endif
   if nargin == 1, w = 2.5; endif
   x = exp ( -0.5 * ( w/L * [ -(L-1) : 2 : L-1 ]' ) .^ 2 );
 
