@@ -1,6 +1,6 @@
 ## Copyright (C) 1995, 1996, 1997 Kurt Hornik <Kurt.Hornik@ci.tuwien.ac.at>
 ## Copyright (C) 2000 Paul Kienzle <pkienzle@users.sf.net>
-## 
+##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
 ## Foundation; either version 3 of the License, or (at your option) any later
@@ -14,7 +14,9 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## usage:  kaiser (L, beta)
+## -*- texinfo -*-
+## @deftypefn  {Function File} {} kaiser (@var{L})
+## @deftypefnx {Function File} {} kaiser (@var{L}, @var{beta})
 ##
 ## Returns the filter coefficients of the L-point Kaiser window with
 ## parameter beta.
@@ -24,11 +26,16 @@
 ##
 ## The continuous version of width L centered about x=0 is:
 ##
+## @example
+## @group
 ##         besseli(0, beta * sqrt(1-(2*x/L).^2))
 ## k(x) =  -------------------------------------,  L/2 <= x <= L/2
 ##                besseli(0, beta)
+## @end group
+## @end example
 ##
-## See also: kaiserord
+## @seealso{kaiserord}
+## @end deftypefn
 
 function w = kaiser (L, beta = 0.5)
 
@@ -39,7 +46,7 @@ function w = kaiser (L, beta = 0.5)
   elseif !(isscalar (beta) && (beta == real (beta)))
     error ("kaiser:  beta has to be a real scalar");
   endif
-  
+
   if (L == 1)
     w = 1;
   else
