@@ -14,9 +14,9 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{Q} = } marcumq (@var{a}, @var{b})
-## @deftypefnx {Function File} {@var{Q} = } marcumq (@var{a}, @var{b}, @var{m})
-## @deftypefnx {Function File} {@var{Q} = } marcumq (@var{a}, @var{b}, @var{m}, @var{tol})
+## @deftypefn  {Function File} {@var{Q} =} marcumq (@var{a}, @var{b})
+## @deftypefnx {Function File} {@var{Q} =} marcumq (@var{a}, @var{b}, @var{m})
+## @deftypefnx {Function File} {@var{Q} =} marcumq (@var{a}, @var{b}, @var{m}, @var{tol})
 ##
 ## Compute the generalized Marcum Q function of order @var{M} with
 ## noncentrality parameter @var{a} and argument @var{b}.  If the order
@@ -29,7 +29,7 @@
 ## This function computes Marcum's Q function using the infinite
 ## Bessel series, truncated when the relative error is less than
 ## the specified tolerance.  The accuracy is limited by that of
-## the Bessel functions, so reducing the tolerance is probably 
+## the Bessel functions, so reducing the tolerance is probably
 ## not useful.
 ##
 ## Reference: Marcum, "Tables of Q Functions", Rand Corporation.
@@ -43,37 +43,39 @@ function Q = marcumq(a,b,M=1,tol=eps)
 
   if ( (nargin<2) || (nargin>4) )
     print_usage();
-  end
+  endif
   if ( any(a<0) || any(b<0) )
     error("Parameters to marcumq must be positive");
-  end
+  endif
   if ( any(M<0) || any(floor(M)~=M) )
     error("M must be a positive integer");
-  end
+  endif
 
   [a,b,M] = tablify(a,b,M);
 
   Q = arrayfun(@mq, a,b,M,tol);
 
-end
+endfunction
+
+## Subfunction to compute the actual Marcum Q function.
 
-% Subfunction to compute the actual Marcum Q function.
 function Q = mq(a,b,M,tol)
-  % Special cases.
+
+  ## Special cases.
   if (b==0)
     Q = 1;
     N = 0;
     return;
-  end
+  endif
   if (a==0)
     k = 0:(M-1);
     Q = exp(-b^2/2)*sum(b.^(2*k)./(2.^k .* factorial(k)));
     N = 0;
     return;
-  end
+  endif
 
-  % The basic iteration.  If a<b compute Q_M, otherwise
-  % compute 1-Q_M.
+  ## The basic iteration.  If a<b compute Q_M, otherwise
+  ## compute 1-Q_M.
   k = M;
   z = a*b;
   t = 1;
@@ -88,7 +90,7 @@ function Q = mq(a,b,M,tol)
       t = (d+1/d)*besseli(k,z,1);
       S = S + t;
       d = d*x;
-    end
+    endfor
     N=k++;
   else
     s = -1;
@@ -98,7 +100,7 @@ function Q = mq(a,b,M,tol)
     d = x^M;
     S = 0;
     N = 0;
-  end
+  endif
 
   do
     t = d*besseli(abs(k),z,1);
@@ -107,10 +109,10 @@ function Q = mq(a,b,M,tol)
     N = k++;
   until (abs(t/S)<tol)
   Q = c + s*exp( -(a-b)^2/2 )*S;
-end
 
-%  Tests for number and validity of arguments.
-%
+endfunction
+
+%% Tests for number and validity of arguments.
 %!error
 %! fail(marcumq(1))
 %!error
@@ -124,27 +126,27 @@ end
 %!error
 %! fail(marcumq(1,1,1.1))
 
-%  Notes on tests and accuracy.
-%  -----------------------------------
-%  The numbers used as the reference (Q) in the tables below are
-%  from J.I. Marcum, "Table of Q Functions", Rand Technical Report
-%  RM-339, 1950/1/1.
-%
-%  There is one discrepency in the tables.  Marcum has
-%    Q(14.00,17.10) = 0.001078
-%  while we compute 
-%    Q(14.00,17.10) = 0.0010785053 = 0.001079
-%  This is obviously a non-problem.
-%
-%  As further tests, I created several different versions of the
-%  Q function computation, including a Bessel series expansion and
-%  numerical integration.  All of them agree to with 10^(-16).
+## Notes on tests and accuracy.
+## -----------------------------------
+## The numbers used as the reference (Q) in the tables below are
+## from J.I. Marcum, "Table of Q Functions", Rand Technical Report
+## RM-339, 1950/1/1.
+##
+## There is one discrepency in the tables.  Marcum has
+##   Q(14.00,17.10) = 0.001078
+## while we compute
+##   Q(14.00,17.10) = 0.0010785053 = 0.001079
+## This is obviously a non-problem.
+##
+## As further tests, I created several different versions of the
+## Q function computation, including a Bessel series expansion and
+## numerical integration.  All of them agree to with 10^(-16).
 
 %!test
 %! a = [0.00;0.05;1.00;2.00;3.00;4.00;5.00;6.00;7.00;8.00;9.00;10.00;
 %!      11.00;12.00;13.00;14.00;15.00;16.00;17.00;18.00;19.00;20.00;
 %!      21.00;22.00;23.00;24.00];
-%! b = [0.000000, 0.100000, 1.100000, 2.100000, 3.100000, 4.100000]; 
+%! b = [0.000000, 0.100000, 1.100000, 2.100000, 3.100000, 4.100000];
 %! Q = [1.000000, 0.995012, 0.546074, 0.110251, 0.008189, 0.000224;
 %!      1.000000, 0.995019, 0.546487, 0.110554, 0.008238, 0.000226;
 %!      1.000000, 0.996971, 0.685377, 0.233113, 0.034727, 0.002092;
@@ -170,7 +172,7 @@ end
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
-%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000]; 
+%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000];
 %! q = marcumq(a,b);
 %! assert(q,Q,1e-6);
 
@@ -178,7 +180,7 @@ end
 %! a = [0.00;0.05;1.00;2.00;3.00;4.00;5.00;6.00;7.00;8.00;9.00;10.00;
 %!      11.00;12.00;13.00;14.00;15.00;16.00;17.00;18.00;19.00;20.00;
 %!      21.00;22.00;23.00;24.00];
-%! b = [5.100000, 6.100000, 7.100000, 8.100000, 9.100000, 10.10000]; 
+%! b = [5.100000, 6.100000, 7.100000, 8.100000, 9.100000, 10.10000];
 %! Q = [0.000002, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000;
 %!      0.000002, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000;
 %!      0.000049, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000;
@@ -204,7 +206,7 @@ end
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
-%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000]; 
+%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000];
 %! q = marcumq(a,b);
 %! assert(q,Q,1e-6);
 
@@ -213,7 +215,7 @@ end
 %! a = [0.00;0.05;1.00;2.00;3.00;4.00;5.00;6.00;7.00;8.00;9.00;10.00;
 %!      11.00;12.00;13.00;14.00;15.00;16.00;17.00;18.00;19.00;20.00;
 %!      21.00;22.00;23.00;24.00];
-%! b = [11.10000, 12.10000, 13.10000, 14.10000, 15.10000, 16.10000]; 
+%! b = [11.10000, 12.10000, 13.10000, 14.10000, 15.10000, 16.10000];
 %! Q = [0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000;
 %!      0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000;
 %!      0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000;
@@ -239,7 +241,7 @@ end
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
-%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000]; 
+%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000];
 %! q = marcumq(a,b);
 %! assert(q,Q,1e-6);
 
@@ -248,7 +250,7 @@ end
 %! a = [0.00;0.05;1.00;2.00;3.00;4.00;5.00;6.00;7.00;8.00;9.00;10.00;
 %!      11.00;12.00;13.00;14.00;15.00;16.00;17.00;18.00;19.00;20.00;
 %!      21.00;22.00;23.00;24.00];
-%! b = [17.10000, 18.10000, 19.10000]; 
+%! b = [17.10000, 18.10000, 19.10000];
 %! Q = [0.000000, 0.000000, 0.000000;
 %!      0.000000, 0.000000, 0.000000;
 %!      0.000000, 0.000000, 0.000000;
@@ -274,19 +276,19 @@ end
 %!      0.999957, 0.998281, 0.972883;
 %!      1.000000, 0.999957, 0.998274;
 %!      1.000000, 1.000000, 0.999956;
-%!      1.000000, 1.000000, 1.000000]; 
+%!      1.000000, 1.000000, 1.000000];
 %! q = marcumq(a,b);
 %! assert(q,Q,1e-6);
 
-%  The tests for M>1 were generating from Marcum's tables by
-%  using the formula
-%    Q_M(a,b) = Q(a,b) + exp(-(a-b)^2/2)*sum_{k=1}^{M-1}(b/a)^k*exp(-ab)*I_k(ab)
-%
+## The tests for M>1 were generating from Marcum's tables by
+## using the formula
+##   Q_M(a,b) = Q(a,b) + exp(-(a-b)^2/2)*sum_{k=1}^{M-1}(b/a)^k*exp(-ab)*I_k(ab)
+
 %!test
 %! M = 2;
 %! a = [0.00;0.05;1.00;2.00;3.00;4.00;5.00;6.00;7.00;8.00;9.00;10.00;11.00;12.00;13.00;14.00;15.00;16.00;17.00;18.00;19.00;20.00;21.00;22.00;23.00;24.000000];
-%! 
-%! b = [    0.00,     0.10,     2.10,     7.10,    12.10,    17.10]; 
+%!
+%! b = [    0.00,     0.10,     2.10,     7.10,    12.10,    17.10];
 %! Q = [1.000000, 0.999987, 0.353353, 0.000000, 0.000000, 0.000000;
 %!      1.000000, 0.999988, 0.353687, 0.000000, 0.000000, 0.000000;
 %!      1.000000, 0.999992, 0.478229, 0.000000, 0.000000, 0.000000;
@@ -312,15 +314,15 @@ end
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 0.999966;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
-%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000]; 
+%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000];
 %! q = marcumq(a,b,M);
 %! assert(q,Q,1e-6);
 
 %!test
 %! M = 5;
 %! a = [0.00;0.05;1.00;2.00;3.00;4.00;5.00;6.00;7.00;8.00;9.00;10.00;11.00;12.00;13.00;14.00;15.00;16.00;17.00;18.00;19.00;20.00;21.00;22.00;23.00;24.000000];
-%! 
-%! b = [    0.00,     0.10,     2.10,     7.10,    12.10,    17.10]; 
+%!
+%! b = [    0.00,     0.10,     2.10,     7.10,    12.10,    17.10];
 %! Q = [1.000000, 1.000000, 0.926962, 0.000000, 0.000000, 0.000000;
 %!      1.000000, 1.000000, 0.927021, 0.000000, 0.000000, 0.000000;
 %!      1.000000, 1.000000, 0.947475, 0.000001, 0.000000, 0.000000;
@@ -346,15 +348,15 @@ end
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 0.999983;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
-%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000]; 
+%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000];
 %! q = marcumq(a,b,M);
 %! assert(q,Q,1e-6);
 
 %!test
 %! M = 10;
 %! a = [0.00;0.05;1.00;2.00;3.00;4.00;5.00;6.00;7.00;8.00;9.00;10.00;11.00;12.00;13.00;14.00;15.00;16.00;17.00;18.00;19.00;20.00;21.00;22.00;23.00;24.000000];
-%! 
-%! b = [    0.00,     0.10,     2.10,     7.10,    12.10,    17.10]; 
+%!
+%! b = [    0.00,     0.10,     2.10,     7.10,    12.10,    17.10];
 %! Q = [1.000000, 1.000000, 0.999898, 0.000193, 0.000000, 0.000000;
 %!      1.000000, 1.000000, 0.999897, 0.000194, 0.000000, 0.000000;
 %!      1.000000, 1.000000, 0.999931, 0.000416, 0.000000, 0.000000;
@@ -380,6 +382,6 @@ end
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 0.999995;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
 %!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000;
-%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000]; 
+%!      1.000000, 1.000000, 1.000000, 1.000000, 1.000000, 1.000000];
 %! q = marcumq(a,b,M);
 %! assert(q,Q,1e-6);
