@@ -14,16 +14,18 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{psi,x}] =} mexihat(@var{lb,ub,n})
+## @deftypefn {Function File} {[@var{psi,x}] =} mexihat (@var{lb,ub,n})
 ## Compute the Mexican hat wavelet.
 ## @end deftypefn
 
 function [psi,x] = mexihat(lb,ub,n)
-  if (nargin < 3); print_usage; end
+
+  if (nargin < 3); print_usage; endif
 
   if (n <= 0)
     error("n must be strictly positive");
   endif
   x = linspace(lb,ub,n);
   psi = (1-x.^2).*(2/(sqrt(3)*pi^0.25)) .* exp(-x.^2/2)  ;
+
 endfunction
