@@ -14,12 +14,14 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{y}] =} meyeraux(@var{x})
+## @deftypefn {Function File} {[@var{y}] =} meyeraux (@var{x})
 ## Compute the Meyer wavelet auxiliary function.
 ## @end deftypefn
 
 function [y] = meyeraux(x)
-  if (nargin < 1); print_usage; end
+
+  if (nargin < 1); print_usage; endif
 
   y = 35.*x.^4-84.*x.^5+70.*x.^6-20.*x.^7;
+
 endfunction
