@@ -14,22 +14,23 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{w}] =} nuttallwin(@var{L})
-## Compute the Blackman-Harris window defined by Nuttall of length L.
+## @deftypefn {Function File} {[@var{w}] =} nuttallwin (@var{L})
+## Compute the Blackman-Harris window defined by Nuttall of length @var{L}.
 ## @seealso{blackman, blackmanharris}
 ## @end deftypefn
 
 function [w] = nuttallwin(L)
-  if (nargin != 1); print_usage; end
+
+  if (nargin != 1); print_usage; endif
 
   if(L < 0)
     error('L must be positive');
-  end
+  endif
 
   if(L ~= floor(L))
     L = round(L);
     warning('L rounded to the nearest integer.');
-  end
+  endif
 
   if (L == 1)
     w = 1;
@@ -43,4 +44,5 @@ function [w] = nuttallwin(L)
     w = a0 + a1.*cos(2.*pi.*n./N) + a2.*cos(4.*pi.*n./N) + a3.*cos(6.*pi.*n./N);
     w = w';
   endif
+
 endfunction
