@@ -13,8 +13,11 @@
 ## You should have received a copy of the GNU General Public License along with
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
-## usage: y=pulstran(t,d,'func',...)
-##        y=pulstran(t,d,p,Fs,'interp')
+## -*- texinfo -*-
+## @deftypefn  {Function File} {@var{y} =} pulstran (@var{t}, @var{d}, @var{func}, @dots{})
+## @deftypefnx {Function File} {@var{y} =} pulstran (@var{t}, @var{d}, @var{p})
+## @deftypefnx {Function File} {@var{y} =} pulstran (@var{t}, @var{d}, @var{p}, @var{Fs})
+## @deftypefnx {Function File} {@var{y} =} pulstran (@var{t}, @var{d}, @var{p}, @var{Fs}, @var{method})
 ##
 ## Generate the signal y=sum(func(t+d,...)) for each d.  If d is a
 ## matrix of two columns, the first column is the delay d and the second
@@ -22,11 +25,13 @@
 ## Clearly, func must be a function which accepts a vector of times.
 ## Any extra arguments needed for the function must be tagged on the end.
 ##
-## Example
-##   fs = 11025;  # arbitrary sample rate
-##   f0 = 100;    # pulse train sample rate
-##   w = 0.001;   # pulse width of 1 millisecond
-##   auplot(pulstran(0:1/fs:0.1, 0:1/f0:0.1, 'rectpuls', w), fs);
+## Example:
+## @example
+## fs = 11025;  # arbitrary sample rate
+## f0 = 100;    # pulse train sample rate
+## w = 0.001;   # pulse width of 1 millisecond
+## auplot (pulstran (0:1/fs:0.1, 0:1/f0:0.1, "rectpuls", w), fs);
+## @end example
 ##
 ## If instead of a function name you supply a pulse shape sampled at
 ## frequency Fs (default 1 Hz),  an interpolated version of the pulse
@@ -35,15 +40,18 @@
 ## to linear, but it can be any interpolation method accepted by the
 ## function interp1.
 ##
-## Example
-##   fs = 11025;  # arbitrary sample rate
-##   f0 = 100;    # pulse train sample rate
-##   w = boxcar(10);  # pulse width of 1 millisecond at 10 kHz
-##   auplot(pulstran(0:1/fs:0.1, 0:1/f0:0.1, w, 10000), fs);
+## Example:
+## @example
+## fs = 11025;      # arbitrary sample rate
+## f0 = 100;        # pulse train sample rate
+## w = boxcar(10);  # pulse width of 1 millisecond at 10 kHz
+## auplot (pulstran (0:1/fs:0.1, 0:1/f0:0.1, w, 10000), fs);
+## @end example
+## @end deftypefn
 
-## TODO: Make it faster.  It is currently unusable for anything real.
-## TODO: It may not be possible to speed it up with the present interface.
-## TODO: See speech/voice.m for a better way.
+## FIXME: Make it faster.  It is currently unusable for anything real.
+##        It may not be possible to speed it up with the present interface.
+##        See speech/voice.m for a better way.
 
 ## Note that pulstran can be used for some pretty strange things such
 ## as simple band-limited interpolation:
@@ -95,6 +103,7 @@ function y = pulstran(t, d, pulse, varargin)
       y(idx) = y(idx) + a(i)*interp1(t_pulse, pulse, dt(idx), method);
     endfor
   endif
+
 endfunction
 
 %!error pulstran
@@ -119,24 +128,36 @@ endfunction
 %! t = 0:1/fs:0.1; d=0:1/f0:0.1; # define sample times and pulse times
 %! a = hanning(length(d));       # define pulse amplitudes
 %!
-%! subplot(221); title("rectpuls");
-%! auplot(pulstran(t', d', 'rectpuls', w), fs);
+%! subplot(221);
+%! x = pulstran(t', d', 'rectpuls', w);
+%! plot([0:length(x)-1]*1000/fs, x);
 %! hold on; plot(d*1000,ones(size(d)),'g*;pulse;'); hold off;
+%! ylabel("amplitude"); xlabel("time (ms)");
+%! title("rectpuls");
 %!
-%! subplot(223); title("sinc => band limited interpolation");
-%! auplot(pulstran(f0*t, [f0*d', a], 'sinc'), fs);
+%! subplot(223);
+%! x = pulstran(f0*t, [f0*d', a], 'sinc');
+%! plot([0:length(x)-1]*1000/fs, x);
 %! hold on; plot(d*1000,a,'g*;pulse;'); hold off;
+%! ylabel("amplitude"); xlabel("time (ms)");
+%! title("sinc => band limited interpolation");
 %!
-%! subplot(222); title("interpolated boxcar");
+%! subplot(222);
 %! pulse = boxcar(30);  # pulse width of 3 ms at 10 kHz
-%! auplot(pulstran(t, d', pulse, 10000), fs);
+%! x = pulstran(t, d', pulse, 10000);
+%! plot([0:length(x)-1]*1000/fs, x);
 %! hold on; plot(d*1000,ones(size(d)),'g*;pulse;'); hold off;
+%! ylabel("amplitude"); xlabel("time (ms)");
+%! title("interpolated boxcar");
 %!
-%! subplot(224); title("interpolated asymmetric sin");
+%! subplot(224);
 %! pulse = sin(2*pi*[0:0.0001:w]/w).*[w:-0.0001:0];
-%! auplot(pulstran(t', [d', a], pulse', 10000), fs);
+%! x = pulstran(t', [d', a], pulse', 10000);
+%! plot([0:length(x)-1]*1000/fs, x);
 %! hold on; plot(d*1000,a*w,'g*;pulse;'); hold off; title("");
-%! 
+%! ylabel("amplitude"); xlabel("time (ms)");
+%! title("interpolated asymmetric sin");
+%!
 %! %----------------------------------------------------------
 %! % Should see (1) rectangular pulses centered on *,
 %! %            (2) rectangular pulses to the right of *,
