@@ -14,12 +14,14 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{w}] =} rectwin(@var{L})
-## Return the filter coefficients of a rectangle window of length L.
+## @deftypefn {Function File} {[@var{w}] =} rectwin (@var{L})
+## Return the filter coefficients of a rectangle window of length @var{L}.
 ## @seealso{hamming, hanning}
 ## @end deftypefn
 
 function w = rectwin(L)
-  if (nargin < 1); print_usage; end
+
+  if (nargin < 1); print_usage; endif
   w = ones(round(L),1);
+
 endfunction
