@@ -14,13 +14,15 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{w} =} window (@var{f}, @var{n}, @var{opts})
-## Create a @var{n}-point windowing from the function @var{f}. The
-## function @var{f} can be for example @code{@@blackman}. Any additional
+## @deftypefn  {Function File} {@var{w} =} window (@var{f}, @var{n})
+## @deftypefnx {Function File} {@var{w} =} window (@var{f}, @var{n}, @var{opts})
+## Create an @var{n}-point window from the function @var{f}.  The function
+## @var{f} can be for example @code{@@blackman}.  Any additional
 ## arguments @var{opt} are passed to the windowing function.
-## @end deftypefn 
+## @end deftypefn
 
 function wout = window (f, n, varargin)
+
   if (nargin == 0)
     error ("window: UI tool not supported");
   elseif (nargin > 1)
@@ -31,4 +33,5 @@ function wout = window (f, n, varargin)
   else
     print_usage ();
   endif
+
 endfunction
