@@ -78,44 +78,46 @@ void CreateDenseGrid(int r, int numtaps, int numband, const double bands[],
                      double Grid[], double D[], double W[],
                      int symmetry, int griddensity)
 {
-   int i, j, k, band;
-   double delf, lowf, highf, grid0;
+  int i, j, k, band;
+  double delf, lowf, highf, grid0;
 
-   delf = 0.5/(griddensity*r);
+  delf = 0.5/(griddensity*r);
 
-/*
- * For differentiator, hilbert,
- *   symmetry is odd and Grid[0] = max(delf, bands[0])
- */
-   grid0 = (symmetry == NEGATIVE) && (delf > bands[0]) ? delf : bands[0];
+  /*
+   * For differentiator, hilbert,
+   *   symmetry is odd and Grid[0] = max(delf, bands[0])
+   */
+  grid0 = (symmetry == NEGATIVE) && (delf > bands[0]) ? delf : bands[0];
 
-   j=0;
-   for (band=0; band < numband; band++)
-   {
+  j=0;
+  for (band=0; band < numband; band++)
+    {
       lowf = (band==0 ? grid0 : bands[2*band]);
       highf = bands[2*band + 1];
       k = (int)((highf - lowf)/delf + 0.5);   /* .5 for rounding */
+      if (band == 0 && symmetry == NEGATIVE)
+        k--;
       for (i=0; i<k; i++)
-      {
-         D[j] = des[2*band] + i*(des[2*band+1]-des[2*band])/(k-1);
-         W[j] = weight[band];
-         Grid[j] = lowf;
-         lowf += delf;
-         j++;
-      }
+        {
+          D[j] = des[2*band] + i*(des[2*band+1]-des[2*band])/(k-1);
+          W[j] = weight[band];
+          Grid[j] = lowf;
+          lowf += delf;
+          j++;
+        }
       Grid[j-1] = highf;
-   }
+    }
 
 /*
  * Similar to above, if odd symmetry, last grid point can't be .5
  *  - but, if there are even taps, leave the last grid point at .5
  */
-   if ((symmetry == NEGATIVE) &&
+  if ((symmetry == NEGATIVE) &&
        (Grid[gridsize-1] > (0.5 - delf)) &&
        (numtaps % 2))
-   {
+    {
       Grid[gridsize-1] = 0.5-delf;
-   }
+    }
 }
 
 
@@ -125,7 +127,7 @@ void CreateDenseGrid(int r, int numtaps, int numband, const double bands[],
  * Places Extremal Frequencies evenly throughout the dense grid.
  *
  *
- * INPUT: 
+ * INPUT:
  * ------
  * int r        - 1/2 the number of filter coefficients
  * int gridsize - Number of elements in the dense frequency grid
@@ -137,10 +139,10 @@ void CreateDenseGrid(int r, int numtaps, int numband, const double bands[],
 
 void InitialGuess(int r, int Ext[], int gridsize)
 {
-   int i;
+  int i;
 
-   for (i=0; i<=r; i++)
-      Ext[i] = i * (gridsize-1) / r;
+  for (i=0; i<=r; i++)
+    Ext[i] = i * (gridsize-1) / r;
 }
 
 
@@ -165,58 +167,58 @@ void InitialGuess(int r, int Ext[], int gridsize)
  ***********************/
 
 void CalcParms(int r, int Ext[], double Grid[], double D[], double W[],
-                double ad[], double x[], double y[])
+               double ad[], double x[], double y[])
 {
-   int i, j, k, ld;
-   double sign, xi, delta, denom, numer;
+  int i, j, k, ld;
+  double sign, xi, delta, denom, numer;
 
-/*
- * Find x[]
- */
-   for (i=0; i<=r; i++)
-      x[i] = cos(Pi2 * Grid[Ext[i]]);
+  /*
+   * Find x[]
+   */
+  for (i=0; i<=r; i++)
+    x[i] = cos(Pi2 * Grid[Ext[i]]);
 
-/*
- * Calculate ad[]  - Oppenheim & Schafer eq 7.132
- */
-   ld = (r-1)/15 + 1;         /* Skips around to avoid round errors */
-   for (i=0; i<=r; i++)
-   {
-       denom = 1.0;
-       xi = x[i];
-       for (j=0; j<ld; j++)
-       {
+  /*
+   * Calculate ad[]  - Oppenheim & Schafer eq 7.132
+   */
+  ld = (r-1)/15 + 1;         /* Skips around to avoid round errors */
+  for (i=0; i<=r; i++)
+    {
+      denom = 1.0;
+      xi = x[i];
+      for (j=0; j<ld; j++)
+        {
           for (k=j; k<=r; k+=ld)
-             if (k != i)
-                denom *= 2.0*(xi - x[k]);
-       }
-       if (fabs(denom)<0.00001)
-          denom = 0.00001;
-       ad[i] = 1.0/denom;
-   }
+            if (k != i)
+              denom *= 2.0*(xi - x[k]);
+        }
+      if (fabs(denom)<0.00001)
+        denom = 0.00001;
+      ad[i] = 1.0/denom;
+    }
 
-/*
- * Calculate delta  - Oppenheim & Schafer eq 7.131
- */
-   numer = denom = 0;
-   sign = 1;
-   for (i=0; i<=r; i++)
-   {
+  /*
+   * Calculate delta  - Oppenheim & Schafer eq 7.131
+   */
+  numer = denom = 0;
+  sign = 1;
+  for (i=0; i<=r; i++)
+    {
       numer += ad[i] * D[Ext[i]];
       denom += sign * ad[i]/W[Ext[i]];
       sign = -sign;
-   }
-   delta = numer/denom;
-   sign = 1;
+    }
+  delta = numer/denom;
+  sign = 1;
 
-/*
- * Calculate y[]  - Oppenheim & Schafer eq 7.133b
- */
-   for (i=0; i<=r; i++)
-   {
+  /*
+   * Calculate y[]  - Oppenheim & Schafer eq 7.133b
+   */
+  for (i=0; i<=r; i++)
+    {
       y[i] = D[Ext[i]] - sign * delta/W[Ext[i]];
       sign = -sign;
-   }
+    }
 }
 
 
@@ -243,25 +245,25 @@ void CalcParms(int r, int Ext[], double Grid[], double D[], double W[],
 
 double ComputeA(double freq, int r, double ad[], double x[], double y[])
 {
-   int i;
-   double xc, c, denom, numer;
+  int i;
+  double xc, c, denom, numer;
 
-   denom = numer = 0;
-   xc = cos(Pi2 * freq);
-   for (i=0; i<=r; i++)
-   {
+  denom = numer = 0;
+  xc = cos(Pi2 * freq);
+  for (i=0; i<=r; i++)
+    {
       c = xc - x[i];
       if (fabs(c) < 1.0e-7)
-      {
-         numer = y[i];
-         denom = 1;
-         break;
-      }
+        {
+          numer = y[i];
+          denom = 1;
+          break;
+        }
       c = ad[i]/c;
       denom += c;
       numer += c*y[i];
-   }
-   return numer/denom;
+    }
+  return numer/denom;
 }
 
 
@@ -293,14 +295,14 @@ void CalcError(int r, double ad[], double x[], double y[],
                int gridsize, double Grid[],
                double D[], double W[], double E[])
 {
-   int i;
-   double A;
+  int i;
+  double A;
 
-   for (i=0; i<gridsize; i++)
-   {
+  for (i=0; i<gridsize; i++)
+    {
       A = ComputeA(Grid[i], r, ad, x, y);
       E[i] = W[i] * (D[i] - A);
-   }
+    }
 }
 
 /************************
@@ -328,121 +330,121 @@ void CalcError(int r, double ad[], double x[], double y[],
  * int    Ext[]    - New indexes to extremal frequencies [r+1]
  ************************/
 int Search(int r, int Ext[],
-            int gridsize, double E[])
+           int gridsize, double E[])
 {
-   int i, j, k, l, extra;     /* Counters */
-   int up, alt;
-   int *foundExt;             /* Array of found extremals */
+  int i, j, k, l, extra;     /* Counters */
+  int up, alt;
+  int *foundExt;             /* Array of found extremals */
 
-/*
- * Allocate enough space for found extremals.
- */
-   foundExt = (int *)malloc((2*r) * sizeof(int));
-   k = 0;
+  /*
+   * Allocate enough space for found extremals.
+   */
+  foundExt = (int *)malloc((2*r) * sizeof(int));
+  k = 0;
 
-/*
- * Check for extremum at 0.
- */
-   if (((E[0]>0.0) && (E[0]>E[1])) ||
-       ((E[0]<0.0) && (E[0]<E[1])))
-      foundExt[k++] = 0;
+  /*
+   * Check for extremum at 0.
+   */
+  if (((E[0]>0.0) && (E[0]>E[1])) ||
+      ((E[0]<0.0) && (E[0]<E[1])))
+    foundExt[k++] = 0;
 
-/*
- * Check for extrema inside dense grid
- */
-   for (i=1; i<gridsize-1; i++)
-   {
+  /*
+   * Check for extrema inside dense grid
+   */
+  for (i=1; i<gridsize-1; i++)
+    {
       if (((E[i]>=E[i-1]) && (E[i]>E[i+1]) && (E[i]>0.0)) ||
           ((E[i]<=E[i-1]) && (E[i]<E[i+1]) && (E[i]<0.0))) {
-	// PAK: we sometimes get too many extremal frequencies
-	if (k >= 2*r) return -3;
-	foundExt[k++] = i;
+        // PAK: we sometimes get too many extremal frequencies
+        if (k >= 2*r) return -3;
+        foundExt[k++] = i;
       }
-   }
+    }
 
-/*
- * Check for extremum at 0.5
- */
-   j = gridsize-1;
-   if (((E[j]>0.0) && (E[j]>E[j-1])) ||
+  /*
+   * Check for extremum at 0.5
+   */
+  j = gridsize-1;
+  if (((E[j]>0.0) && (E[j]>E[j-1])) ||
        ((E[j]<0.0) && (E[j]<E[j-1]))) {
-     if (k >= 2*r) return -3;
-     foundExt[k++] = j;
-   }
+    if (k >= 2*r) return -3;
+    foundExt[k++] = j;
+  }
 
-   // PAK: we sometimes get not enough extremal frequencies
-   if (k < r+1) return -2;
+  // PAK: we sometimes get not enough extremal frequencies
+  if (k < r+1) return -2;
 
 
-/*
- * Remove extra extremals
- */
-   extra = k - (r+1);
-   assert(extra >= 0);
+  /*
+   * Remove extra extremals
+   */
+  extra = k - (r+1);
+  assert(extra >= 0);
 
-   while (extra > 0)
-   {
+  while (extra > 0)
+    {
       if (E[foundExt[0]] > 0.0)
-         up = 1;                /* first one is a maxima */
+        up = 1;                /* first one is a maxima */
       else
-         up = 0;                /* first one is a minima */
+        up = 0;                /* first one is a minima */
 
       l=0;
       alt = 1;
       for (j=1; j<k; j++)
-      {
-         if (fabs(E[foundExt[j]]) < fabs(E[foundExt[l]]))
+        {
+          if (fabs(E[foundExt[j]]) < fabs(E[foundExt[l]]))
             l = j;               /* new smallest error. */
-         if ((up) && (E[foundExt[j]] < 0.0))
+          if ((up) && (E[foundExt[j]] < 0.0))
             up = 0;             /* switch to a minima */
-         else if ((!up) && (E[foundExt[j]] > 0.0))
+          else if ((!up) && (E[foundExt[j]] > 0.0))
             up = 1;             /* switch to a maxima */
-         else
-	 { 
-            alt = 0;
-	    // PAK: break now and you will delete the smallest overall
-	    // extremal.  If you want to delete the smallest of the
-	    // pair of non-alternating extremals, then you must do:
-            //
-	    // if (fabs(E[foundExt[j]]) < fabs(E[foundExt[j-1]])) l=j;
-	    // else l=j-1;
-            break;              /* Ooops, found two non-alternating */
-         }                      /* extrema.  Delete smallest of them */
-      }  /* if the loop finishes, all extrema are alternating */
+          else
+            {
+              alt = 0;
+              // PAK: break now and you will delete the smallest overall
+              // extremal.  If you want to delete the smallest of the
+              // pair of non-alternating extremals, then you must do:
+              //
+              // if (fabs(E[foundExt[j]]) < fabs(E[foundExt[j-1]])) l=j;
+              // else l=j-1;
+              break;              /* Ooops, found two non-alternating */
+            }                     /* extrema.  Delete smallest of them */
+        }  /* if the loop finishes, all extrema are alternating */
 
-/*
- * If there's only one extremal and all are alternating,
- * delete the smallest of the first/last extremals.
- */
+      /*
+       * If there's only one extremal and all are alternating,
+       * delete the smallest of the first/last extremals.
+       */
       if ((alt) && (extra == 1))
-      {
-         if (fabs(E[foundExt[k-1]]) < fabs(E[foundExt[0]]))
-	   /* Delete last extremal */
-	   l = k-1;
-	   // PAK: changed from l = foundExt[k-1]; 
-         else
-	   /* Delete first extremal */
-	   l = 0;
-	   // PAK: changed from l = foundExt[0];     
-      }
+        {
+          if (fabs(E[foundExt[k-1]]) < fabs(E[foundExt[0]]))
+            /* Delete last extremal */
+            l = k-1;
+            // PAK: changed from l = foundExt[k-1];
+          else
+            /* Delete first extremal */
+            l = 0;
+            // PAK: changed from l = foundExt[0];
+        }
 
       for (j=l; j<k-1; j++)        /* Loop that does the deletion */
-      {
-         foundExt[j] = foundExt[j+1];
-	 assert(foundExt[j]<gridsize);
-      }
+        {
+          foundExt[j] = foundExt[j+1];
+          assert(foundExt[j]<gridsize);
+        }
       k--;
       extra--;
-   }
+    }
 
-   for (i=0; i<=r; i++)
-   {
+  for (i=0; i<=r; i++)
+    {
       assert(foundExt[i]<gridsize);
       Ext[i] = foundExt[i];       /* Copy found extremals to Ext[] */
-   }
+    }
 
-   free(foundExt);
-   return 0;
+  free(foundExt);
+  return 0;
 }
 
 
@@ -465,60 +467,60 @@ int Search(int r, int Ext[],
  *********************/
 void FreqSample(int N, double A[], double h[], int symm)
 {
-   int n, k;
-   double x, val, M;
+  int n, k;
+  double x, val, M;
 
-   M = (N-1.0)/2.0;
-   if (symm == POSITIVE)
-   {
+  M = (N-1.0)/2.0;
+  if (symm == POSITIVE)
+    {
       if (N%2)
-      {
-         for (n=0; n<N; n++)
-         {
-            val = A[0];
-            x = Pi2 * (n - M)/N;
-            for (k=1; k<=M; k++)
-               val += 2.0 * A[k] * cos(x*k);
-            h[n] = val/N;
-         }
-      }
-      else
-      {
-         for (n=0; n<N; n++)
-         {
-            val = A[0];
-            x = Pi2 * (n - M)/N;
-            for (k=1; k<=(N/2-1); k++)
-               val += 2.0 * A[k] * cos(x*k);
-            h[n] = val/N;
-         }
-      }
-   }
-   else
-   {
-      if (N%2)
-      {
-         for (n=0; n<N; n++)
-         {
-            val = 0;
-            x = Pi2 * (n - M)/N;
-            for (k=1; k<=M; k++)
-               val += 2.0 * A[k] * sin(x*k);
-            h[n] = val/N;
-         }
-      }
-      else
-      {
+        {
           for (n=0; n<N; n++)
-          {
-             val = A[N/2] * sin(Pi * (n - M));
-             x = Pi2 * (n - M)/N;
-             for (k=1; k<=(N/2-1); k++)
+            {
+              val = A[0];
+              x = Pi2 * (n - M)/N;
+              for (k=1; k<=M; k++)
+                val += 2.0 * A[k] * cos(x*k);
+              h[n] = val/N;
+            }
+        }
+      else
+        {
+          for (n=0; n<N; n++)
+            {
+              val = A[0];
+              x = Pi2 * (n - M)/N;
+              for (k=1; k<=(N/2-1); k++)
+                val += 2.0 * A[k] * cos(x*k);
+              h[n] = val/N;
+            }
+        }
+    }
+  else
+    {
+      if (N%2)
+        {
+          for (n=0; n<N; n++)
+            {
+              val = 0;
+              x = Pi2 * (n - M)/N;
+              for (k=1; k<=M; k++)
                 val += 2.0 * A[k] * sin(x*k);
-             h[n] = val/N;
-          }
-      }
-   }
+              h[n] = val/N;
+            }
+        }
+      else
+        {
+          for (n=0; n<N; n++)
+            {
+              val = A[N/2] * sin(Pi * (n - M));
+              x = Pi2 * (n - M)/N;
+              for (k=1; k<=(N/2-1); k++)
+                val += 2.0 * A[k] * sin(x*k);
+              h[n] = val/N;
+            }
+        }
+    }
 }
 
 /*******************
@@ -541,19 +543,19 @@ void FreqSample(int N, double A[], double h[], int symm)
 
 int isDone(int r, int Ext[], double E[])
 {
-   int i;
-   double min, max, current;
+  int i;
+  double min, max, current;
 
-   min = max = fabs(E[Ext[0]]);
-   for (i=1; i<=r; i++)
-   {
+  min = max = fabs(E[Ext[0]]);
+  for (i=1; i<=r; i++)
+    {
       current = fabs(E[Ext[i]]);
       if (current < min)
-         min = current;
+        min = current;
       if (current > max)
-         max = current;
-   }
-   return (((max-min)/max) < 0.0001);
+        max = current;
+    }
+  return (((max-min)/max) < 0.0001);
 }
 
 /********************
@@ -580,185 +582,198 @@ int isDone(int r, int Ext[], double E[])
  ********************/
 
 int remez(double h[], int numtaps,
-	  int numband, const double bands[], 
-	  const double des[], const double weight[],
-	  int type, int griddensity)
+          int numband, const double bands[],
+          const double des[], const double weight[],
+          int type, int griddensity)
 {
-   double *Grid, *W, *D, *E;
-   int    i, iter, gridsize, r, *Ext;
-   double *taps, c;
-   double *x, *y, *ad;
-   int    symmetry;
+  double *Grid, *W, *D, *E;
+  int    i, iter, gridsize, r, *Ext;
+  double *taps, c;
+  double *x, *y, *ad;
+  int    symmetry;
 
-   if (type == BANDPASS)
-      symmetry = POSITIVE;
-   else
-      symmetry = NEGATIVE;
+  if (type == BANDPASS)
+    symmetry = POSITIVE;
+  else
+    symmetry = NEGATIVE;
 
-   r = numtaps/2;                  /* number of extrema */
-   if ((numtaps%2) && (symmetry == POSITIVE))
-      r++;
+  r = numtaps/2;                  /* number of extrema */
+  if ((numtaps%2) && (symmetry == POSITIVE))
+    r++;
 
-/*
- * Predict dense grid size in advance for memory allocation
- *   .5 is so we round up, not truncate
- */
-   gridsize = 0;
-   for (i=0; i<numband; i++)
-   {
+  /*
+   * Predict dense grid size in advance for memory allocation
+   *   .5 is so we round up, not truncate
+   */
+  gridsize = 0;
+  for (i=0; i<numband; i++)
+    {
       gridsize += (int)(2*r*griddensity*(bands[2*i+1] - bands[2*i]) + .5);
-   }
-   if (symmetry == NEGATIVE)
-   {
+    }
+  if (symmetry == NEGATIVE)
+    {
       gridsize--;
-   }
+    }
 
-/*
- * Dynamically allocate memory for arrays with proper sizes
- */
-   Grid = (double *)malloc(gridsize * sizeof(double));
-   D = (double *)malloc(gridsize * sizeof(double));
-   W = (double *)malloc(gridsize * sizeof(double));
-   E = (double *)malloc(gridsize * sizeof(double));
-   Ext = (int *)malloc((r+1) * sizeof(int));
-   taps = (double *)malloc((r+1) * sizeof(double));
-   x = (double *)malloc((r+1) * sizeof(double));
-   y = (double *)malloc((r+1) * sizeof(double));
-   ad = (double *)malloc((r+1) * sizeof(double));
+  /*
+   * Dynamically allocate memory for arrays with proper sizes
+   */
+  Grid = (double *)malloc(gridsize * sizeof(double));
+  D = (double *)malloc(gridsize * sizeof(double));
+  W = (double *)malloc(gridsize * sizeof(double));
+  E = (double *)malloc(gridsize * sizeof(double));
+  Ext = (int *)malloc((r+1) * sizeof(int));
+  taps = (double *)malloc((r+1) * sizeof(double));
+  x = (double *)malloc((r+1) * sizeof(double));
+  y = (double *)malloc((r+1) * sizeof(double));
+  ad = (double *)malloc((r+1) * sizeof(double));
 
-/*
- * Create dense frequency grid
- */
-   CreateDenseGrid(r, numtaps, numband, bands, des, weight,
-                   gridsize, Grid, D, W, symmetry, griddensity);
-   InitialGuess(r, Ext, gridsize);
+  /*
+   * Create dense frequency grid
+   */
+  CreateDenseGrid(r, numtaps, numband, bands, des, weight,
+                  gridsize, Grid, D, W, symmetry, griddensity);
+  InitialGuess(r, Ext, gridsize);
 
-/*
- * For Differentiator: (fix grid)
- */
-   if (type == DIFFERENTIATOR)
-   {
+  /*
+   * For Differentiator: (fix grid)
+   */
+  if (type == DIFFERENTIATOR)
+    {
       for (i=0; i<gridsize; i++)
-      {
-/* D[i] = D[i]*Grid[i]; */
-         if (D[i] > 0.0001)
+        {
+          /* D[i] = D[i]*Grid[i]; */
+          if (D[i] > 0.0001)
             W[i] = W[i]/Grid[i];
-      }
-   }
+        }
+    }
 
-/*
- * For odd or Negative symmetry filters, alter the
- * D[] and W[] according to Parks McClellan
- */
-   if (symmetry == POSITIVE)
-   {
+  /*
+   * For odd or Negative symmetry filters, alter the
+   * D[] and W[] according to Parks McClellan
+   */
+  if (symmetry == POSITIVE)
+    {
       if (numtaps % 2 == 0)
-      {
-         for (i=0; i<gridsize; i++)
-         {
-            c = cos(Pi * Grid[i]);
-            D[i] /= c;
-            W[i] *= c; 
-         }
-      }
-   }
-   else
-   {
+        {
+          for (i=0; i<gridsize; i++)
+            {
+              c = cos(Pi * Grid[i]);
+              D[i] /= c;
+              W[i] *= c;
+            }
+        }
+    }
+  else
+    {
       if (numtaps % 2)
-      {
-         for (i=0; i<gridsize; i++)
-         {
-            c = sin(Pi2 * Grid[i]);
-            D[i] /= c;
-            W[i] *= c;
-         }
-      }
+        {
+          for (i=0; i<gridsize; i++)
+            {
+              c = sin(Pi2 * Grid[i]);
+              D[i] /= c;
+              W[i] *= c;
+            }
+        }
       else
-      {
-         for (i=0; i<gridsize; i++)
-         {
-            c = sin(Pi * Grid[i]);
-            D[i] /= c;
-            W[i] *= c;
-         }
-      }
-   }
+        {
+          for (i=0; i<gridsize; i++)
+            {
+              c = sin(Pi * Grid[i]);
+              D[i] /= c;
+              W[i] *= c;
+            }
+        }
+    }
 
-/*
- * Perform the Remez Exchange algorithm
- */
-   for (iter=0; iter<MAXITERATIONS; iter++)
-   {
+  /*
+   * Perform the Remez Exchange algorithm
+   */
+  for (iter=0; iter<MAXITERATIONS; iter++)
+    {
       CalcParms(r, Ext, Grid, D, W, ad, x, y);
       CalcError(r, ad, x, y, gridsize, Grid, D, W, E);
       int err = Search(r, Ext, gridsize, E);
       if (err) return err;
       for(int i=0; i <= r; i++) assert(Ext[i]<gridsize);
       if (isDone(r, Ext, E))
-         break;
-   }
+        break;
+    }
 
-   CalcParms(r, Ext, Grid, D, W, ad, x, y);
+  CalcParms(r, Ext, Grid, D, W, ad, x, y);
 
-/*
- * Find the 'taps' of the filter for use with Frequency
- * Sampling.  If odd or Negative symmetry, fix the taps
- * according to Parks McClellan
- */
-   for (i=0; i<=numtaps/2; i++)
-   {
+  /*
+   * Find the 'taps' of the filter for use with Frequency
+   * Sampling.  If odd or Negative symmetry, fix the taps
+   * according to Parks McClellan
+   */
+  for (i=0; i<=numtaps/2; i++)
+    {
       if (symmetry == POSITIVE)
-      {
-         if (numtaps%2)
+        {
+          if (numtaps%2)
             c = 1;
-         else
+          else
             c = cos(Pi * (double)i/numtaps);
-      }
+        }
       else
-      {
-         if (numtaps%2)
+        {
+          if (numtaps%2)
             c = sin(Pi2 * (double)i/numtaps);
-         else
+          else
             c = sin(Pi * (double)i/numtaps);
-      }
+        }
       taps[i] = ComputeA((double)i/numtaps, r, ad, x, y)*c;
-   }
+    }
 
-/*
- * Frequency sampling design with calculated taps
- */
-   FreqSample(numtaps, taps, h, symmetry);
+  /*
+   * Frequency sampling design with calculated taps
+   */
+  FreqSample(numtaps, taps, h, symmetry);
 
-/*
- * Delete allocated memory
- */
-   free(Grid);
-   free(W);
-   free(D);
-   free(E);
-   free(Ext);
-   free(x);
-   free(y);
-   free(ad);
-   return iter<MAXITERATIONS?0:-1;
+  /*
+   * Delete allocated memory
+   */
+  free(Grid);
+  free(W);
+  free(D);
+  free(E);
+  free(Ext);
+  free(x);
+  free(y);
+  free(ad);
+  return iter<MAXITERATIONS?0:-1;
 }
 
 
 /* == Octave interface starts here ====================================== */
 
 DEFUN_DLD (remez, args, ,
-  "b = remez(n, f, a [, w] [, ftype] [, griddensity])\n\
+  "-*- texinfo -*-\n\
+@deftypefn  {Loadable Function} {@var{b} =} remez (@var{n}, @var{f}, @var{a})\n\
+@deftypefnx {Loadable Function} {@var{b} =} remez (@var{n}, @var{f}, @var{a}, @var{w})\n\
+@deftypefnx {Loadable Function} {@var{b} =} remez (@var{n}, @var{f}, @var{a}, @var{w}, @var{ftype})\n\
+@deftypefnx {Loadable Function} {@var{b} =} remez (@var{n}, @var{f}, @var{a}, @var{w}, @var{ftype}, @var{griddensity})\n\
 Parks-McClellan optimal FIR filter design.\n\
-n gives the number of taps in the returned filter\n\
-f gives frequency at the band edges [ b1 e1 b2 e2 b3 e3 ...]\n\
-a gives amplitude at the band edges [ a(b1) a(e1) a(b2) a(e2) ...]\n\
-w gives weighting applied to each band\n\
-ftype is 'bandpass', 'hilbert' or 'differentiator'\n\
-griddensity determines how accurately the filter will be\n\
-    constructed. The minimum value is 16, but higher numbers are\n\
-    slower to compute.\n\
+@table @var\n\
+@item n\n\
+gives the number of taps in the returned filter\n\
+@item f\n\
+gives frequency at the band edges [b1 e1 b2 e2 b3 e3 @dots{}]\n\
+@item a\n\
+gives amplitude at the band edges [a(b1) a(e1) a(b2) a(e2) @dots{}]\n\
+@item w\n\
+gives weighting applied to each band\n\
+@item ftype\n\
+is \"bandpass\", \"hilbert\" or \"differentiator\"\n\
+@item griddensity\n\
+determines how accurately the filter will be\n\
+constructed. The minimum value is 16, but higher numbers are\n\
+slower to compute.\n\
+@end table\n\
 \n\
-Frequency is in the range (0, 1), with 1 being the nyquist frequency")
+Frequency is in the range (0, 1), with 1 being the Nyquist frequency.\n\
+@end deftypefn")
 {
   octave_value_list retval;
   int i;
@@ -812,8 +827,8 @@ Frequency is in the range (0, 1), with 1 being the nyquist frequency")
     else if (args(3).is_real_matrix() || args(3).is_real_scalar()) {
       ColumnVector o_weight(args(3).vector_value());
       if (o_weight.length() != numbands) {
-	error("remez: need one weight for each band [=length(band)/2]");
-	return retval;
+        error("remez: need one weight for each band [=length(band)/2]");
+        return retval;
       }
       for (i=0; i < numbands; i++) weight[i] = o_weight(i);
     }
@@ -834,7 +849,7 @@ Frequency is in the range (0, 1), with 1 being the nyquist frequency")
   }
   if (nargin > 5) {
     if (args(5).is_real_scalar()
-	&& !args(4).is_real_scalar())
+        && !args(4).is_real_scalar())
       density = NINT(args(5).double_value());
     else {
       error("remez: incorrect argument list");
@@ -843,11 +858,11 @@ Frequency is in the range (0, 1), with 1 being the nyquist frequency")
   }
 
   int itype;
-  if (stype == "bandpass") 
+  if (stype == "bandpass")
     itype = BANDPASS;
-  else if (stype == "differentiator") 
+  else if (stype == "differentiator")
     itype = DIFFERENTIATOR;
-  else if (stype == "hilbert") 
+  else if (stype == "hilbert")
     itype = HILBERT;
   else {
     error("remez: unknown ftype '%s'", stype.data());
